@@ -298,6 +298,9 @@ ourC2hs bi lbi _ = PreProcessor {
 #else
 ourC2hs :: BuildInfo -> LocalBuildInfo -> PreProcessor
 ourC2hs bi lbi = PreProcessor {
+#endif
+#if MIN_VERSION_Cabal(3,8,1)
+  ppOrdering = \_ _ ms -> return ms,
 #endif
   platformIndependent = False,
   runPreProcessor = runC2HS bi lbi
